@@ -19,10 +19,13 @@
 import base64
 import json
 import logging
+import math
+import mimetypes
+import os
 import time
 from collections import namedtuple
 from configparser import ConfigParser
-from hashlib import sha256
+from hashlib import sha256, md5
 
 from pyrogram.api import functions, types
 from pyrogram.api.core import Object
@@ -254,6 +257,8 @@ class Client:
         self.rnd_id = self.session.msg_id
         self.get_dialogs()
 
+        mimetypes.init()
+
     def stop(self):
         self.session.stop()
 
@@ -494,3 +499,102 @@ class Client:
                 revoke=revoke or None
             )
         )
+
+    def save_file(self, path):
+        file_size = os.path.getsize(path)
+        file_total_parts = math.ceil(file_size / 512 / 1024)
+        is_big = True if file_size >= 10 * 1024 * 1024 else False
+        session = Session(self.dc_id, self.test_mode, self.auth_key, self.config.api_id)
+
+        try:
+            session.start()
+
+            file_id = session.msg_id()
+            md5_sum = md5()
+
+            with open(path, "rb") as f:
+                file_part = 0
+
+                while True:
+                    chunk = f.read(512 * 1024)
+
+                    if not chunk:
+                        md5_sum = md5_sum.digest().hex()
+                        break
+
+                    md5_sum.update(chunk)
+
+                    session.send(
+                        (functions.upload.SaveBigFilePart if is_big else functions.upload.SaveFilePart)(
+                            file_id=file_id,
+                            file_part=file_part,
+                            bytes=chunk,
+                            file_total_parts=file_total_parts
+                        )
+                    )
+
+                    file_part += 1
+        except Exception as e:
+            log.error(e)
+        else:
+            return types.InputFile(
+                id=file_id,
+                parts=file_part,
+                name=os.path.basename(path),
+                md5_checksum=md5_sum
+            )
+        finally:
+            session.stop()
+
+    def send_photo(self,
+                   chat_id: int or str,
+                   photo: str,
+                   caption: str = "",
+                   ttl_seconds: int = None,
+                   disable_notification: bool = None,
+                   reply_to_message_id: int = None):
+        return self.send(
+            functions.messages.SendMedia(
+                peer=self.resolve_peer(chat_id),
+                media=types.InputMediaUploadedPhoto(
+                    file=self.save_file(photo),
+                    caption=caption,
+                    ttl_seconds=ttl_seconds
+                ),
+                silent=disable_notification or None,
+                reply_to_msg_id=reply_to_message_id,
+                random_id=self.rnd_id()
+            )
+        )
+
+    def send_audio(self,
+                   chat_id: int or str,
+                   audio: str,
+                   caption: str = "",
+                   duration: int = 0,
+                   performer: str = None,
+                   title: str = None,
+                   disable_notification: bool = None,
+                   reply_to_message_id: int = None):
+
+        return self.send(
+            functions.messages.SendMedia(
+                peer=self.resolve_peer(chat_id),
+                media=types.InputMediaUploadedDocument(
+                    mime_type=mimetypes.types_map["." + audio.split(".")[-1]],
+                    file=self.save_file(audio),
+                    caption=caption,
+                    attributes=[
+                        types.DocumentAttributeAudio(
+                            duration=duration,
+                            performer=performer,
+                            title=title
+                        ),
+                        types.DocumentAttributeFilename(os.path.basename(audio))
+                    ]
+                ),
+                silent=disable_notification or None,
+                reply_to_msg_id=reply_to_message_id,
+                random_id=self.rnd_id()
+            )
+        )
